@@ -1,11 +1,11 @@
 from pydantic import BaseModel, Field
-from datetime import datetime
+from datetime import date
 
 
 class WaterLevelObservation(BaseModel):
     lon: float = Field(..., title="Longitude")
     lat: float = Field(..., title="Latitude")
-    date: datetime
+    date: date
     waterlevel: float = Field(alias="waterlevel_ocog")
     elevation: float = Field(alias="elevation_ocog")
     geoid_height: float
