@@ -6,13 +6,11 @@ from pydantic import BaseModel
 from .aoi import AOI
 
 
-
 class SceneBase(BaseModel):
     request_id: str
     scene_id: str
 
 
-
 class SceneSummary(SceneBase):
     scene_name: str
     tile: str = None
@@ -34,11 +32,10 @@ class SceneSummary(SceneBase):
     def get_tile_name_from_scene(self):
         name = self.scene_id.split("_")[1]
         if len(name) != 5:
-            name = "0" + name
+            name = f"0{name}"
         return name
 
 
-
 class Scene(SceneSummary):
     aoi: Optional[AOI]
     scl_href_url: Optional[str]
